# Changelog


## 1.0.0

- Initial release

### 1.0.1

- Enhance robustness for cases where database interface arguments are not provided as configuration parameters (via `dict.get`)
- Improve aesthetics of docs table of contents
- Add more documentation for the `SQLAlchemy` object
